@@ -709,7 +709,7 @@ def copy_cloud_eval_files(main_dir):
 
 
 def copy_documentation_files(target_dir):
-    source_dir = os.path.join(__location__, 'documentation/')
+    source_dir = os.path.join(__location__, 'dsframework/documentation/')
 
     for (dirpath, dirname, filenames) in os.walk(source_dir):
         doc_files = [os.path.join(dirpath, file) for file in filenames if file != 'dsf_doxyfile']
