@@ -121,8 +121,8 @@ class ZIDS_Tester:
             for row_key in self.data_keys:
                 del rec[row_key]
 
-            rec['target'] = json.dumps(pred_dict)
-            rec['pred'] = json.dumps(target_dict)
+            rec['target'] = json.dumps(target_dict)
+            rec['pred'] = json.dumps(pred_dict)
 
         return output
 
